package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcYqZs;

/**
 * 舆情走势图Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-28
 */
public interface TcYqZsMapper 
{
    /**
     * 查询舆情走势图
     * 
     * @param id 舆情走势图主键
     * @return 舆情走势图
     */
    public TcYqZs selectTcYqZsById(Long id);

    /**
     * 查询舆情走势图列表
     * 
     * @param tcYqZs 舆情走势图
     * @return 舆情走势图集合
     */
    public List<TcYqZs> selectTcYqZsList(TcYqZs tcYqZs);

    /**
     * 新增舆情走势图
     * 
     * @param tcYqZs 舆情走势图
     * @return 结果
     */
    public int insertTcYqZs(TcYqZs tcYqZs);

    /**
     * 修改舆情走势图
     * 
     * @param tcYqZs 舆情走势图
     * @return 结果
     */
    public int updateTcYqZs(TcYqZs tcYqZs);

    /**
     * 删除舆情走势图
     * 
     * @param id 舆情走势图主键
     * @return 结果
     */
    public int deleteTcYqZsById(Long id);

    /**
     * 批量删除舆情走势图
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcYqZsByIds(Long[] ids);
}
